package it.unibs.arnaldo.rovineperdute;

/**
 * Classe che rappresenta una coordinata nello spazio tridimensionale.
 * Contiene le coordinate x, y e l'altezza.
 */
public class Coordinata {
    private final int x;
    private final int y;
    private final int altezza;

    /**
     * Costruttore della classe Coordinata.
     * @param x la coordinata x
     * @param y la coordinata y
     * @param altezza l'altezza della coordinata
     */
    public Coordinata(int x, int y, int altezza){
        this.altezza = altezza;
        this.x = x;
        this.y = y;
    }

    /**
     * Getter per la coordinata x
     * @return la coordinata x
     */
    public int getX() {
        return x;
    }

    /**
     * Getter per la coordinata y
     * @return la coordinata y
     */
    public int getY() {
        return y;
    }

    /**
     * Getter per l'altezza della coordinata
     * @return l'altezza della coordinata
     */
    public int getAltezza() {
        return altezza;
    }


    @Override
    public String toString() {
        return "Coordinata{" +
                "x=" + x +
                ", y=" + y +
                ", altezza=" + altezza +
                '}';
    }

    /**
     * Calcola la distanza tra questa coordinata e un'altra coordinata in base al tipo di veicolo.
     * @param c la coordinata da confrontare
     * @param tipoVeicolo il tipo di veicolo utilizzato per calcolare la distanza
     * @return la distanza calcolata, o -1 se il tipo di veicolo non è riconosciuto
     */
    public double calcolaDistanza(Coordinata c, TipoVeicolo tipoVeicolo){
        if (tipoVeicolo == TipoVeicolo.METZTLI){
            return Math.abs(altezza - c.getAltezza());
        } else if (tipoVeicolo == TipoVeicolo.TONATIUH){
            return Math.sqrt(Math.pow(x - c.getX(), 2) + Math.pow(y - c.getY(), 2));
        }

        return -1;
    }
}
