package it.unibs.arnaldo.rovineperdute;

/**
 * Classe che estende RovinaPerduta per rappresentare una rovina perduta con una distanza specifica.
 * Questa classe è utilizzata per gestire le rovine perdute in un grafo, dove la distanza rappresenta
 */
public class RovinaPerdutaGrafo extends RovinaPerduta{
    private final double distanza;

    /**
     * Costruttore della classe RovinaPerdutaGrafo.
     * @param coordinata la coordinata della rovina perduta
     * @param nome il nome della rovina perduta
     * @param id l'ID della rovina perduta
     * @param distanza la distanza dalla rovina perduta
     */
    public RovinaPerdutaGrafo(Coordinata coordinata, String nome, int id, double distanza) {
        super(coordinata, nome, id);
        this.distanza = distanza;
    }

    /**
     * Getter per la distanza della rovina perduta.
     * @return la distanza dalla rovina perduta
     */
    public double getDistanza() {
        return distanza;
    }

    @Override
    public String toString(){
        return getNome() + " (" + getCoordinata().getX() + ", " + getCoordinata().getY() + ", " + getCoordinata().getAltezza() + ") Distanza: " + distanza;
    }
}
