package it.unibs.arnaldo.rovineperdute;

import java.util.List;

/**
 * Classe che gestisce le operazioni sulle rovine perdute, come il calcolo degli spanning tree
 * e la generazione di un file XML contenente le informazioni sulle rovine.
 */
public class RovinePerduteHandler {
    private final Graph grafo;
    private final List<RovinaPerdutaGrafo> minimumTreeMetztli;
    private final List<RovinaPerdutaGrafo> minimumTreeTonatium;

    /**
     * Costruttore della classe RovinePerduteHandler.
     * Inizializza il grafo delle rovine perdute e calcola gli spanning tree per i veicoli Metztli e Tonatiuh.
     * @param filename il nome del file XML da cui leggere le informazioni sulle rovine perdute
     */
    public RovinePerduteHandler(String filename) {

        this.grafo = Parser.parseRovinePerduteXML(filename);
        RovinaPerduta partenza = null;
        for (RovinaPerduta rp : grafo.getGraph().keySet()){
            if (rp.getId() == 0){
                partenza = rp;
                break;
            }
        }
        this.minimumTreeMetztli = grafo.calcolaSpanningTree(partenza, TipoVeicolo.METZTLI);
        this.minimumTreeTonatium = grafo.calcolaSpanningTree(partenza, TipoVeicolo.TONATIUH);
    }

    /**
     * Metodo per ottenere il file XML contenente le informazioni sulle rovine perdute.
     */
    public void generaFileXML(){
        Parser.generaXML(minimumTreeTonatium, minimumTreeMetztli);
    }
}
